module.exports = defineTest({
	description: 'properly associate or shadow variables in and around for-of-loops'
});
